@@ -71,6 +71,17 @@ def format_long_dict_list(data):
     return ',\n'.join(newdata) + '\n'
 
 
+def format_dict(data):
+    """Return a formatted string.
+
+    :param data: a dict
+    :rtype: a string formatted to {a:b, c:d}
+    """
+    if not isinstance(data, dict):
+        return str(data)
+    return str({str(key): str(value) for key, value in data.items()})
+
+
 def format_list(data):
     """Return a formatted strings
 
@@ -122,7 +133,7 @@ def get_resource_id_from_name(name, results):
         # NOTE(arosen): this should only occur is using congress
         # as admin and multiple tenants use the same datsource name.
         raise exceptions.Conflict(
-            "Multiple resources have this name %s. Delete by id." % name)
+            "Multiple resources have this name %s. Please specify id." % name)
     if id_match:
         return id_match
 
